#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_7_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_7_HPP_INCLUDED

#include <boost/simd/constant/include/constants/oneo_7.hpp>

#endif
